import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _extends from "@babel/runtime/helpers/extends";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormGroupWrapper from '../form-group/form-group';
import { Select as BSelect, MultiSelect } from '@blueprintjs/select';
import propsCatcher from '../props-catcher/props-catcher';
import { MenuItem } from "@blueprintjs/core/lib/esm/components/menu/menuItem.js";
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";

var _itemRenderer = function itemRenderer(item, _ref, value) {
  var handleClick = _ref.handleClick;
  return /*#__PURE__*/React.createElement(MenuItem, _extends({
    key: item.value
  }, item, !item.text && {
    label: '',
    text: item.label
  }, {
    onClick: handleClick,
    icon: item.value === value || Array.isArray(value) && value.includes(item.value) ? 'tick' : 'blank'
  }));
};

export { _itemRenderer as itemRenderer };
export var multiOnChange = function multiOnChange(item, input) {
  return input.value && !input.value.includes(item.value) ? input.onChange([].concat(_toConsumableArray(input.value), [item.value])) : input.onChange(input.value ? input.value.filter(function (v) {
    return v !== item.value;
  }) : [item.value]);
};

var _tagRenderer = function tagRenderer(item, options) {
  var option = options.find(function (_ref2) {
    var value = _ref2.value;
    return value === item;
  });

  if (option) {
    return option.text || option.label;
  }
};

export { _tagRenderer as tagRenderer };
export var itemPredicate = function itemPredicate(query, item) {
  if (!query) {
    return item;
  }

  if (item.label.toLowerCase().includes(query.toLowerCase())) {
    return item;
  }
};

var Select = function Select(_ref3) {
  var input = _ref3.input,
      options = _ref3.options,
      placeholder = _ref3.placeholder,
      isSearchable = _ref3.isSearchable,
      noOptionsMessage = _ref3.noOptionsMessage,
      isMulti = _ref3.isMulti,
      props = _objectWithoutProperties(_ref3, ["input", "options", "placeholder", "isSearchable", "noOptionsMessage", "isMulti"]);

  var Component = isMulti ? MultiSelect : BSelect;
  var selectedOption = options.find(function (_ref4) {
    var value = _ref4.value;
    return value === input.value;
  });
  return /*#__PURE__*/React.createElement(Component, _extends({
    itemPredicate: itemPredicate,
    onItemSelect: function onItemSelect(_ref5) {
      var value = _ref5.value;
      return input.onChange(value);
    },
    noResults: /*#__PURE__*/React.createElement(MenuItem, {
      disabled: true,
      text: noOptionsMessage
    }),
    items: options,
    itemRenderer: function itemRenderer(item, args) {
      return _itemRenderer(item, args, input.value);
    },
    filterable: isSearchable
  }, propsCatcher(props), isMulti && {
    selectedItems: input.value || [],
    tagRenderer: function tagRenderer(item) {
      return _tagRenderer(item, options);
    },
    onItemSelect: function onItemSelect(item) {
      return multiOnChange(item, input);
    },
    tagInputProps: _objectSpread(_objectSpread({}, props.tagInputProps), {}, {
      onRemove: function onRemove(item) {
        return multiOnChange({
          value: item
        }, input);
      }
    })
  }, input), !isMulti && /*#__PURE__*/React.createElement(Button, {
    text: selectedOption ? selectedOption.label : placeholder,
    rightIcon: "caret-down",
    disabled: props.disabled
  }));
};

Select.propTypes = {
  input: PropTypes.object,
  options: PropTypes.array,
  placeholder: PropTypes.node,
  isSearchable: PropTypes.bool,
  noOptionsMessage: PropTypes.node,
  tagInputProps: PropTypes.object,
  isMulti: PropTypes.bool,
  disabled: PropTypes.bool
};
Select.defaultProps = {
  noOptionsMessage: 'No options found',
  placeholder: 'Please select',
  isSearchable: false
};

var WrapperSelect = function WrapperSelect(props) {
  return /*#__PURE__*/React.createElement(FormGroupWrapper, _extends({}, props, {
    Component: Select
  }));
};

export default WrapperSelect;